@@ -60,9 +60,11 @@ item(_METACITY_TOGGLE_VERBOSE)
 item(_GTK_THEME_VARIANT)
 item(_GTK_FRAME_EXTENTS)
 item(_GTK_SHOW_WINDOW_MENU)
+item(_GTK_WORKAREAS)
 item(_GNOME_PANEL_ACTION)
 item(_GNOME_PANEL_ACTION_MAIN_MENU)
 item(_GNOME_PANEL_ACTION_RUN_DIALOG)
+item(_GNOME_WM_STRUT_AREA)
 item(_METACITY_TIMESTAMP_PING)
 item(_METACITY_FOCUS_SET)
 item(_METACITY_SENTINEL)
